> # FADE TEXT
```
# Module made by x3f on discord (anvil)
from dma import Fade
from dma import CFade

text = """ @@@@@@   @@@  @@@  @@@  @@@  @@@  @@@       
@@@@@@@@  @@@@ @@@  @@@  @@@  @@@  @@@       
@@!  @@@  @@!@!@@@  @@!  @@@  @@!  @@!       
!@!  @!@  !@!!@!@!  !@!  @!@  !@!  !@!       
@!@!@!@!  @!@ !!@!  @!@  !@!  !!@  @!!       
!!!@!!!!  !@!  !!!  !@!  !!!  !!!  !!!       
!!:  !!!  !!:  !!!  :!:  !!:  !!:  !!:       
:!:  !:!  :!:  !:!   ::!!:!   :!:   :!:      
::   :::   ::   ::    ::::     ::   :: ::::  
 :   : :  ::    :      :      :    : :: : :  
                    anvil <3
"""
```
```
# Fading a ascii art text (black-white)
faded_text = fade.blackwhite(text)
print(faded_text)
>>> Output :
```
> ![](https://github.com/venaxyt/fade/blob/main/images/black-white.PNG)
```
# Fading a ascii art text (purple-pink)
faded_text = fade.purplepink(text)
print(faded_text)
>>> Output :
```
> ![](https://github.com/venaxyt/fade/blob/main/images/purple-pink.PNG)
```
# Fading a ascii art text (green-blue)
faded_text = fade.greenblue(text)
print(faded_text)
>>> Output :
```
> ![](https://github.com/venaxyt/fade/blob/main/images/blue-green.PNG)
```
# Fading a ascii art text (darkblue-blue)
faded_text = fade.water(text)
print(faded_text)
>>> Output :
```
> ![](https://github.com/venaxyt/fade/blob/main/images/marin.PNG)
```
# Fading a ascii art text (yellow-red)
faded_text = fade.fire(text)
print(faded_text)
>>> Output :
```
> ![](https://github.com/venaxyt/fade/blob/main/images/fire.PNG)
```
# Fading a ascii art text (pink-red)
faded_text = fade.pinkred(text)
print(faded_text)
>>> Output :
```
> ![](https://github.com/venaxyt/fade/blob/main/images/pink-red.PNG)
```
# Fading a ascii art text (purple-blue)
faded_text = fade.purpleblue(text)
print(faded_text)
>>> Output :
```
> ![](https://github.com/venaxyt/fade/blob/main/images/purple-blue.PNG)
```
# Fading a ascii art text (green-yellow)
faded_text = fade.brazil(text)
print(faded_text)
>>> Output :
```
> ![](https://github.com/venaxyt/fade/blob/main/images/brazil.PNG)
```
# Fading a ascii art text (random)
faded_text = fade.random(text)
print(faded_text)
>>> Output :
```
> ![](https://github.com/venaxyt/fade/blob/main/images/random.PNG)

### **Download** : ``pip install dma``<br>
### **PyPi : https://pypi.org/project/dma**